from .media_server import MediaServer, Zone
from .api import files_search, escape_for_query, playback_repeat, playback_shuffle


def play_album(
    media_server: MediaServer,
    album_artist: str,
    album: str,
    shuffle: bool = False,
    use_play_doctor: bool = False,
    repeat: bool = False,
    zone: Zone = None,
):
    """ Plays an album by a given album artist.

        By default, this call disables shuffle and repeat, so the album can be listened in the intended order.
        set either to None to avoid this and preserve shuffle/repeat state.
        Setting shuffle to True only shuffles order of files in playlist and leaves playback state alone.
    """
    album_artist = escape_for_query(album_artist)
    album = escape_for_query(album)
    if shuffle is False:
        playback_shuffle(media_server, mode="Off", zone=zone)
    query = (
        "[Album Artist]=["
        + album_artist
        + "] [Album]=["
        + album
        + "] ~sort=[Disc #],[Track #]"
    )
    response = files_search(
        media_server,
        query,
        "play",
        shuffle=shuffle,
        use_play_doctor=use_play_doctor,
        zone=zone,
    )
    response.raise_for_status()
    if repeat is not None:
        repeat = "Playlist" if repeat else "Off"
        response = playback_repeat(media_server, mode=repeat, zone=zone)


def play_keyword(
    media_server: MediaServer,
    keyword: str,
    use_play_doctor: bool = False,
    shuffle: bool = True,
    zone: Zone = None,
):
    """ Plays songs given by a specific keyword.
    """
    keyword = escape_for_query(keyword)
    query = "[keywords]=[" + keyword + "]"
    response = files_search(
        media_server,
        query,
        "play",
        use_play_doctor=use_play_doctor,
        shuffle=shuffle,
        zone=zone,
    )
    response.raise_for_status()



from .media_server import MediaServer, Zone
from .api import files_search, escape_for_query
from typing import List, Dict


def query_album(media_server: MediaServer, album_artist: str, album: str) -> Dict:
    """Returns files from an Album by a given Album Artist.
    """
    album_artist = escape_for_query(album_artist)
    album = escape_for_query(album)
    query = (
        "[Album Artist]=["
        + album_artist
        + "] [Album]=["
        + album
        + "] ~sort=[Disc #],[Track #]"
    )
    response = files_search(media_server, query, "MPL")
    return response


def query_keyword(
    media_server: MediaServer, keyword: str, sort_criteria: List[str] = None
) -> Dict:
    """Returns all files tagged with a specific keyword.

    sort_criteria: a list of strings that contain fieldnames by which to sort the result
    """
    keyword = escape_for_query(keyword)
    query = "[keywords]=[" + keyword + "]"
    if sort_criteria is not None:
        query += " ~sort="
        for criterion in sort_criteria:
            query += "[" + criterion + "],"
        query = query[:-1]
    response = files_search(media_server, query, "MPL")
    return response



class PymcwsError(Exception):
    """Base class for exceptions in this module."""

    pass


class UnresolvableKeyError(PymcwsError):
    """Exception raised if access key is unresolvable.

    More specifically, JRiver web services were available, but do not know the given key.

    Attributes:
        key -- The key that could not be resolved
        message -- message as given by jriver web service
    """

    def __init__(self, key, message):
        self.key = key
        self.message = message



import requests
from requests.auth import HTTPBasicAuth
from requests.exceptions import HTTPError
import logging
from xml.etree import ElementTree
import urllib
from datetime import datetime, timedelta
from .exceptions import UnresolvableKeyError


URL_KEYLOOKUP = "http://webplay.jriver.com/libraryserver/lookup"
URL_API = "http://{ip}:{port}/MCWS/v1/"

logger = logging.getLogger(__name__)


class MediaServer:
    def __init__(self, key_id: str, user: str, password: str):
        """Creates an access key and stores data relevant to this key.

        Minimally, the key_id is required. If either username or password is
        'None', then all requests to the server behind this key will be sent
        without authentication. Use the key_id "localhost" to directly connect
        to the jriver instance running on the same machine as the code.
        """

        self.key_id = key_id
        self.user = user
        self.password = password
        self.con_strategy = "unknown"
        self.fields = None
        if self.key_id == "localhost":
            self.local_ip_list = "127.0.0.1"
            self.local_ip = "127.0.0.1"
            self.port = "52199"
            self.con_strategy = "local"
            self.fields = library_fields(self)

    def __str__(self):
        return "Server " + self.key_id + " at " + self.address()

    def credentials(self) -> HTTPBasicAuth:
        """ Retrieves the credentials for this instance in form of a
        HTTPBasicAuth object
        """
        if self.user is None or self.password is None:
            return None
        else:
            return HTTPBasicAuth(self.user, self.password)

    def refresh(self) -> bool:
        """ Identifies the best way to connect to the machine behind the key,
        querying data from jriver web service if necessary.
        Returns true if successful and false otherwise.

        This function does the following:
        # 1) Test if local ip is present and reachable, if true sets connection
             strategy to local and exists
        # 2) Query jriver service for key data, update keyData accordingly
        # 3) Test if local IP is reachable
        # 4) If not, test if remote ip is reachable
        # 5) else machine behind key is unreachable
        # 6) if machine is reachable, update the field list
        """
        logger.debug("Refreshing access key '" + self.key_id + "'")
        # 1) Test if local ip is present and reachable
        if self.con_strategy == "local":
            if self.test_local():
                self.con_strategy = "local"
                logger.debug(
                    "Access key '" + self.key_id + "': con_strategy set to 'local'."
                )
                self.fields = library_fields(self)
                return True
            else:
                self.con_strategy = "unknown"

        # 2) Test query jriver service for key data
        if self.con_strategy == "unknown" or self.con_strategy == "unreachable":
            logger.debug(
                "Access key '"
                + self.key_id
                + "' has con_strategy '"
                + self.con_strategy
                + "' - refreshing."
            )
            self.update_from_jriver()

        # 3) Test if local IP is reachable
        if self.test_local():
            self.con_strategy = "local"
            logger.debug(
                "Access key '" + self.key_id + "': con_strategy set to 'local'."
            )
            self.fields = library_fields(self)
            return True
        # 4) Test if remote ip is reachable
        if self.test_remote():
            self.con_strategy = "remote"
            logger.debug(
                "Access key '" + self.key_id + "': con_strategy set to 'remote'."
            )
            self.fields = library_fields(self)
            return True
        # 5) Machine behind key is unreachable
        return False

    def address(self):
        """ Returns the address of the mediaserver with regard to the currently chosen
            connection strategy. If no strategy was selected, None is returned.
        """
        if self.con_strategy == "local":
            return self.address_local()
        if self.con_strategy == "remote":
            return self.address_remote()
        return None

    def address_local(self):
        """ Returns the local address of the server.

            This method requires that exactly one local_ip is set.
            Call test_local to test which ip from the local_ip_list is working
            and set it automatically.
        """
        if self.local_ip is None or self.port is None:
            return None
        return URL_API.format(ip=self.local_ip, port=self.port)

    def address_remote(self):
        """ Returns the remote address of the server.

            Assuming that the server is configured correctly and reachable,
            this address should always work.
        """
        if self.remote_ip is None or self.port is None:
            return None
        return URL_API.format(ip=self.remote_ip, port=self.port)

    def test_local(self) -> bool:
        for ip in self.local_ip_list:
            try:
                self.local_ip = ip
                endpoint = self.address_local() + "Alive"
                r = requests.get(endpoint, timeout=2, auth=self.credentials())
                if r.status_code == 200:
                    return True
            except requests.exceptions.RequestException as e:
                logger.warn("Failed to connect to local ip: " + self.local_ip)

        return False

    def test_remote(self) -> bool:
        try:
            endpoint = self.address_remote() + "Alive"
            r = requests.get(endpoint, timeout=3, auth=self.credentials())
            if r.status_code == 200:
                return True
        except requests.exceptions.RequestException as e:
            logger.warn("Failed to connect to remote ip: " + self.remote_ip)
        return False

    def update_from_jriver(self):
        """ Contacts the JRiver WebService to retrieve information about the access key.

        Updates the local instance with current data. This usually is called
        automatically in the refresh method and should not usually need to be called
        from outside the class, please consider reporting your usecase if you need to.
        """
        logger.debug("Updating access key '" + self.key_id + "'")
        r = requests.get(URL_KEYLOOKUP, params={"id": self.key_id}, timeout=5)
        r.raise_for_status()
        et = ElementTree.fromstring(r.content)
        if et.attrib["Status"] == "Error":
            logger.error("KeyID '" + self.key_id + "' could not be resolved.'")
            raise UnresolvableKeyError(self.key_id, et.find("msg").text)
        self.key_id = et.find("keyid").text
        self.ip = et.find("ip").text
        self.port = et.find("port").text
        self.local_ip_list = et.find("localiplist").text.split(",")
        self.remote_ip = et.find("ip").text
        self.http_port = et.find("port").text
        self.https_port = et.find("https_port").text
        self.mac_address_list = et.find("macaddresslist").text.split(",")
        self.last_connection = datetime.now()

    def send_request(self, extension: str, payload=None):
        if self.con_strategy == "unknown":
            self.refresh()
        try:
            return self.attempt_request(extension, payload)
        except HTTPError:
            logger.warn(
                "Failed to contact " + self.key_id + " next failure will cause error."
            )
            self.refresh()
            # TODO Better retry handling
            # Currently, renegotiation happens ones, and fails if that fails
            # as well. Need to consider consequences and expand accordingly
            return self.attempt_request(extension, payload)

    def attempt_request(self, extension: str, payload=None):
        """Sends a request to the server specified in key_data

        Requires a filled-out key_data object. Will send a request to the server
        specified in key_data, addressing the endpoint with the payload.
        """

        # Get destination
        if self.address() is None:
            self.refresh()
        endpoint = self.address() + extension
        # prepare payload
        if payload is not None:
            params = urllib.parse.urlencode(payload, quote_via=urllib.parse.quote)
        else:
            params = None
        # choose authentication strategy
        if self.user is None or self.password is None:
            r = requests.get(endpoint, params=params)
        else:
            r = requests.get(endpoint, params=params, auth=self.credentials())
        if r.status_code == 404:
            r.raise_for_status()
        self.lastConnection = datetime.now()
        return r


class Zone:
    """Zones represent targets for playback-related commands.

    Zones are available on a per-server basis and can be retrieved for each
    using MCWS. If you know the id or name of the zone that you want to target,
    you can also create a zone and set id, index or name manually. The missing
    fields do not affect functionality, the best available value is retrieved
    automatically.
    """

    def __init__(self):
        self.id = -1  # Default ID indicating the zone currently selected in MC
        self.index = None
        self.name = None
        self.guid = None
        self.is_dlna = None

    def best_identifier(self):
        """Checks available fields and retirves the best available.

        Use best_identifier_type() to find out what type of identifier was
        returned.
        """
        if self.id is not None:
            return self.id
        if self.name is not None:
            return self.name
        if self.index is not None:
            return self.index
        logger.warn(
            "Unable to determine best identifier "
            + " for Zone. This is probably a bug."
        )

    def best_identifier_type(self):
        """ Returns the type of the best identifier.

        Used in conjunction with best_identifier() to automatically determine
        the best strategy to communicate zones to the MCWS API.
        """
        if self.id is not None:
            return "ID"
        if self.name is not None:
            return "Name"
        if self.index is not None:
            return "Index"
        logger.warn(
            "Unable to determine best identifier type"
            + " for Zone. This is probably a bug."
        )

    def __str__(self):
        return self.name


def library_fields(self: MediaServer):
    response = self.send_request("Library/Fields", {})
    response.raise_for_status()
    result = {}

    # Some fields are not reported by the library fields function
    result["Key"] = {
        "Name": "Key",
        "DataType": "Integer",
        "EditType": "Not editable",
        "Decoder": lambda x: int(x),
    }
    result["Date (readable)"] = {
        "Name": "Date (readable)",
        "DataType": "String",
        "EditType": "Not editable",
        "Decoder": lambda x: x,
    }

    root = ElementTree.fromstring(response.content)
    for item in root:
        name = item.attrib["Name"]
        data_type = item.attrib["DataType"]
        result[name] = {
            "Name": name,
            "DataType": data_type,
            "EditType": item.attrib["EditType"],
        }

        expression = item.attrib.get("Expression", None)
        if expression is not None:
            result[name]["Expression"] = expression

        if (
            data_type == "String"
            or data_type == "Path"
            or data_type == "User"
            or data_type == "Image File"
        ):
            result[name]["Decoder"] = lambda x: x
        elif data_type == "Integer" or data_type == "File Size":
            result[name]["Decoder"] = lambda x: int(x)
        elif data_type == "Date (float)":
            result[name]["Decoder"] = lambda x: parse_jriver_date(x)
        elif data_type == "Date":
            result[name]["Decoder"] = lambda x: datetime.fromtimestamp(int(x))
        elif data_type == "List":
            result[name]["Decoder"] = lambda x: x.split(";")
        elif data_type == "Decimal" or data_type == "Percentage" or data_type == "Time":
            result[name]["Decoder"] = lambda x: float(x.replace(",", "."))
        else:
            result[name]["Decoder"] = lambda x: x
    return result


def parse_jriver_date(jriver_date) -> datetime:
    """ Takes a jriver date float and turns it into a date object
    """
    if jriver_date is None:
        return None
    # Handle locale if necessary
    jriver_date = jriver_date.replace(",", ".")
    days = float(jriver_date)
    # JRiver returns days since midnight 30th december 1899, must convert
    # See https://yabb.jriver.com/interact/index.php/topic,123431.0.html
    date = datetime.strptime("30.12.1899", "%d.%m.%Y")
    date += timedelta(days=days)
    return date



def transform_path(
    files,
    search_for: str,
    replace_with: str,
    win_to_unix: bool = False,
    unix_to_win: bool = False,
):
    """ Helper method that translates Windows and Unix filepaths
    """
    for file in files:
        file = file.replace(search_for, replace_with)
        if win_to_unix:
            file = file.replace("\\", "/")
        elif unix_to_win:
            file = file.replace("/", "\\")
    return files



from .media_server import MediaServer, Zone

# import logging
from xml.etree import ElementTree
from PIL import Image
from io import BytesIO


def alive(media_server: MediaServer):
    response = media_server.send_request("Alive")
    return transform_unstructured_response(response)


#
#   PLAYBACK
#


def playback_play(media_server: MediaServer, zone: Zone = Zone()):
    playback_command(media_server, "Play", zone)


def playback_playpause(media_server: MediaServer, zone: Zone = Zone()):
    playback_command(media_server, "PlayPause", zone)


def playback_stop(media_server: MediaServer, zone: Zone = Zone()):
    playback_command(media_server, "Stop", zone)


def playback_stopall(media_server: MediaServer):
    playback_command(media_server, "StopAll")


def playback_previous(media_server: MediaServer, zone: Zone = Zone()):
    playback_command(media_server, "Previous", zone)


def playback_next(media_server: MediaServer, zone: Zone = Zone()):
    playback_command(media_server, "Next", zone)


def playback_command(media_server: MediaServer, command: str, zone: Zone = Zone()):
    """Issues a playback command to the server.

    Sends a playback command to the given server. Available commands are:
    Play, PlayPause, Pause, Stop, StopAll, Next, Previous.
    Optionally, provide a zone as target for the playback, otherwise the
    zone currently selected in the MC GUI is targeted.
    """

    payload = {"Zone": zone.best_identifier(), "ZoneType": zone.best_identifier_type()}
    extension = "Playback/" + command
    media_server.send_request(extension, payload)


def playback_zones(media_server: MediaServer, see_hidden: bool = False):
    """Returns a list of zones available at the given server.

    see_hidden: If true, zones that were hidden by a user are returned as well.
    """

    see_hidden = "1" if see_hidden else "0"
    payload = {"Hidden": see_hidden}
    response = media_server.send_request("Playback/Zones", payload)
    response.raise_for_status()
    content = transform_unstructured_response(response)
    num_zones = int(content["NumberZones"])
    # The zones are returned a bit unintuitively,
    # requiring this loop to reconstruct them
    zones = []
    for i in range(num_zones):
        zone = Zone()
        zone.index = i
        zone.id = content["ZoneID" + str(i)]
        zone.name = content["ZoneName" + str(i)]
        zone.guid = content["ZoneGUID" + str(i)]
        zone.is_dlna = True if (content["ZoneDLNA" + str(i)] == "1") else False
        zones.append(zone)
    return zones


def playback_position(
    media_server: MediaServer,
    position: int = None,
    relative: int = None,
    zone: Zone = Zone(),
) -> int:
    """Get or set the playback position.

    position: The position to seek to in milliseconds. If left as None,
              position is returned only. Set to -1 to choose default jump length based on media type.
    relative: When set to 1, 'Position' will be added to the current position to allow jumping forward.
              When set to -1, 'Position' will be subtracted from the current position to allow jumping
              backwards. Use a 'Position' of -1 to jump the default amount based on the media type.
    zone:     Target zone for the command.
    returns: The playback position (after changes, if applicable).
    """
    payload = {"Position": position, "Relative": relative}
    if zone is not None:
        payload["Zone"] = zone.best_identifier()
        payload["ZoneType"] = zone.best_identifier_type()
    response = media_server.send_request("Playback/Position", payload)
    response.raise_for_status()
    response = transform_unstructured_response(response)
    return int(response["Position"])


def playback_volume(
    media_server: MediaServer,
    level: float = None,
    relative: bool = False,
    zone: Zone = Zone(),
) -> float:
    """Get or set the playback volume.

    level:    The level as a value between 0 and 1. If left to None, volume is
              returned unchanged.
    relative: If set to False or None, volume will be set to this value.
              if set to True, value will be adjusted by this value.
    zone:     Target zone for the command.
    returns:  Diverging from MCWS, this method only returns the float volume
              after changes have been applied (no additional display string).
    """
    relative = "1" if relative else "0"
    payload = {"Level": level, "Relative": relative}
    if zone is not None:
        payload["Zone"] = zone.best_identifier()
        payload["ZoneType"] = zone.best_identifier_type()
    response = media_server.send_request("Playback/Volume", payload)
    response.raise_for_status()
    response = transform_unstructured_response(response)
    return float(response["Level"])


def playback_mute(
    media_server: MediaServer, set: bool = None, zone: Zone = Zone()
) -> bool:
    """Get or set the mute mode.

    set:     The boolean value representing the new mute state. Leave to None
             to return state only.
    zone:    Target zone for the command.
    returns: The mute state after changes took effect.
    """
    if set is None:
        set = ""
    else:
        set = "1" if set else "0"
    payload = {"Set": set}
    response = media_server.send_request("Playback/Mute", payload)
    response.raise_for_status()
    response = transform_unstructured_response(response)
    return response["State"] == "1"


def playback_repeat(
    media_server: MediaServer, mode: str = None, zone: Zone = Zone()
) -> str:
    """Get or set the repeat mode.

    mode:    The repeat mode, a string of either: Off, Playlist, Track, Stop, Toggle,
             or None to retrieve repeat value
    zone:    Target zone for the command.
    returns: The shuffle state after changes took effect.
    """
    payload = {"Mode": mode}
    if zone is not None:
        payload["Zone"] = zone.best_identifier()
        payload["ZoneType"] = zone.best_identifier_type()
    response = media_server.send_request("Playback/Repeat", payload)
    response.raise_for_status()
    response = transform_unstructured_response(response)
    return response["Mode"]


def playback_shuffle(
    media_server: MediaServer, mode: str = None, zone: Zone = Zone()
) -> str:
    """Get or set the shuffle state.

    mode:    The suffle mode, a string of either: Off, On, Automatic, Toogle, Reshuffle
    zone:    Target zone for the command.
    returns: The shuffle state after changes took effect.
    """
    payload = {"Mode": mode}
    if zone is not None:
        payload["Zone"] = zone.best_identifier()
        payload["ZoneType"] = zone.best_identifier_type()
    response = media_server.send_request("Playback/Shuffle", payload)
    response.raise_for_status()
    response = transform_unstructured_response(response)
    return response["Mode"]


#
#   FILE
#


def file_get_image(
    media_server: MediaServer,
    file,
    type: str = "Thumbnail",
    thumbnail_size: str = None,
    width: int = None,
    height: int = None,
    fill_transparency: str = None,
    square: bool = False,
    pad: bool = False,
    format: str = "jpg",
    transform_to_pil: bool = True,
) -> Image:
    """Returns an image for the given library file.

    file:   A dictionary of tags, as returned by files_search()
    type:   The type of image to get: Thumbnail (default), Full, ThumbnailsBinary
    thumbnail_size: The size of the thumbnail (if type is thumbnail): Small, Medium, Large
    width:  The width for the returned image.
    height: The height for the returned image.
    fill_transparency: A color to fill image transparency with (hex number).
    square: Set to 1 to crop the image to a square aspect ratio.
    pad:    Set to 1 to pad around the image with transparency to fulfil the requested size.
    format: The preferred image format (jpg or png).
    returns: A pillow image if transform_to_pil is True, and a response object otherwise.
    """
    pad = "1" if pad else "0"
    square = "1" if square else "0"
    payload = {
        "Type": type,
        "ThumbnailSize": thumbnail_size,
        "Width": width,
        "Height": height,
        "FillTransparency": fill_transparency,
        "Square": square,
        "Pad": pad,
        "Format": format,
    }
    if file.get("Key", None) is not None:
        payload["File"] = file["Key"]
        payload["FileType"] = "Key"
    else:
        payload["File"] = file["Filename"]
        payload["FileType"] = "Filename"
    response = media_server.send_request("File/GetImage", payload)
    # Error 500 indicates that no cover was present
    if response.status_code == 500:
        return None
    response.raise_for_status()
    if transform_to_pil:
        return Image.open(BytesIO(response.content))
    else:
        return response


#
#   FILES
#


def files_search(
    media_server: MediaServer,
    query: str,
    action: str,
    fields=None,
    use_play_doctor: bool = False,
    shuffle: bool = False,
    no_local_filenames=False,
    zone=None,
):
    payload = {"Action": action, "Query": query}
    if zone is not None:
        payload["Zone"] = zone.best_identifier()
        payload["ZoneType"] = zone.best_identifier_type()
    payload["NoLocalFilenames"] = "1" if no_local_filenames else "0"
    payload["PlayDoctor"] = "1" if use_play_doctor else "0"
    payload["Shuffle"] = "1" if shuffle else "0"
    if fields is not None:
        fields = ",".join(fields)
        payload["Fields"] = fields
    response = media_server.send_request("Files/Search", payload)
    if action != "MPL":
        return response
    else:
        return transform_mpl_response(media_server, response)


#
#   Library
#


def library_values(
    media_server: MediaServer,
    filter: str = None,
    field: str = None,
    files: str = None,
    limit: str = None,
):
    payload = {"Filter": filter, "Field": field, "Files": files, "Limit": limit}
    response = media_server.send_request("Library/Values", payload)
    response.raise_for_status()
    return transform_list_response(response)


#
#   HELPER
#


def transform_unstructured_response(response):
    """Converts the relatively unstructured XML responses from MCWS into
    a dictionary that is easier to process.
    """
    result = {}
    root = ElementTree.fromstring(response.content)
    for child in root:
        result[child.attrib["Name"]] = child.text
    return result


def transform_list_response(response):
    """ Transforms a response containing a list of items into a list of strings.
    """
    result = []
    root = ElementTree.fromstring(response.content)
    for item in root:
        result.append(item.text)
    return result


def transform_mpl_response(media_server, response):
    """ Transforms an MPL response into a list of dictionaries.

    Each dictionary represents one file and contains the fields as keys.
    """
    result = []
    root = ElementTree.fromstring(response.content)
    for item in root:
        tags = {}
        for tag in item:
            name = tag.attrib["Name"]
            tags[name] = media_server.fields[name]["Decoder"](tag.text)
        result.append(tags)
    return result


def get_media_server(access_key: str, username: str, password: str) -> MediaServer:
    """Returns an instance of media server with the given parameters.

    This is mainly syntactical sugar for people that only want to import pymcws
    and be done with it.
    """
    return MediaServer(access_key, username, password)


def escape_for_query(query_part: str) -> str:
    """Escapes all characters reserved by jriver in a natural string.

    Do not put a complete query in here - this method is used to escape
    reserved characters in a natural string that will be used as a query fragment.
    This is usually the content of a field (e.g. an album or artist name).
    """
    query_part = query_part.replace('"', '/"')  # replace " with /"
    query_part = query_part.replace("^", "/^")
    query_part = query_part.replace("[", "/[")
    query_part = query_part.replace("]", "/]")
    return query_part



from setuptools import setup, find_packages

with open("README.md") as readme_file:
    README = readme_file.read()

with open("history.md") as history_file:
    HISTORY = history_file.read()

setup_args = dict(
    name="pymcws",
    version="0.2.0",
    description="Python API for the MCWS interface of JRiver Media Center",
    long_description_content_type="text/markdown",
    long_description=README + "\n\n" + HISTORY,
    license="MIT",
    packages=find_packages(),
    author="Keno März",
    author_email="keno.maerz@gmail.com",
    keywords=["JRiver", "MCWS"],
    url="https://github.com/kenomaerz/pymcws",
    download_url="https://pypi.org/project/pymcws/",
)

install_requires = ["requests", "pillow"]

if __name__ == "__main__":
    setup(**setup_args, install_requires=install_requires)
